summaryrefslogtreecommitdiff
path: root/src/gui/curses/gui-curses-window.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/curses/gui-curses-window.c')
-rw-r--r--src/gui/curses/gui-curses-window.c26
1 files changed, 14 insertions, 12 deletions
diff --git a/src/gui/curses/gui-curses-window.c b/src/gui/curses/gui-curses-window.c
index e22db0bfd..7d601cfa8 100644
--- a/src/gui/curses/gui-curses-window.c
+++ b/src/gui/curses/gui-curses-window.c
@@ -741,15 +741,16 @@ gui_window_string_apply_color_weechat (unsigned char **str, WINDOW *window)
}
/*
* gui_window_string_apply_color_set: apply "set attribute" color code in
* string and move string pointer after
* color in string
* If window is NULL, no color is applied
* but string pointer is moved anyway
*/
void
-gui_window_string_apply_color_set (unsigned char **str, WINDOW *window)
+gui_window_string_apply_color_set_attr (unsigned char **str, WINDOW *window)
{
unsigned char *ptr_string;
@@ -782,15 +783,16 @@ gui_window_string_apply_color_set (unsigned char **str, WINDOW *window)
}
/*
* gui_window_string_apply_color_remove: apply "remove attribute" color code in
* string and move string pointer after
* color in string
* If window is NULL, no color is applied
* but string pointer is moved anyway
*/
void
-gui_window_string_apply_color_remove (unsigned char **str, WINDOW *window)
+gui_window_string_apply_color_remove_attr (unsigned char **str, WINDOW *window)
{
unsigned char *ptr_string;
@@ -741,15 +741,16 @@ gui_window_string_apply_color_weechat (unsigned char **str, WINDOW *window)
}
/*
- * gui_window_string_apply_color_set: apply "set attribute" color code in
- * string and move string pointer after
- * color in string
- * If window is NULL, no color is applied
- * but string pointer is moved anyway
+ * gui_window_string_apply_color_set_attr: apply "set attribute" color code in
+ * string and move string pointer after
+ * color in string
+ * If window is NULL, no color is
+ * applied but string pointer is moved
+ * anyway
*/
void
@@ -782,15 +783,16 @@ gui_window_string_apply_color_set (unsigned char **str, WINDOW *window)
}
/*
- * gui_window_string_apply_color_remove: apply "remove attribute" color code in
- * string and move string pointer after
- * color in string
- * If window is NULL, no color is applied
- * but string pointer is moved anyway
+ * gui_window_string_apply_color_remove_attr: apply "remove attribute" color
+ * code in string and move string
+ * pointer after color in string
+ * If window is NULL, no color is
+ * applied but string pointer is
+ * moved anyway
*/
void